# OneArgoPy
A Python library for accessing and visualizing Argo data.

The recommended installation is via pip (pip install oneargopy).

The included Jupyter notebook (oneargopy_demo.ipynb) demonstrates the basic usage of this library.
